==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/en_GB.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Saved" : "Saved",
    "Saving failed:" : "Saving failed:",
    "File MIME type" : "File MIME type",
    "is" : "is",
    "is not" : "is not",
    "matches" : "matches",
    "does not match" : "does not match",
    "Example: {placeholder}" : "Example: {placeholder}",
    "File size (upload)" : "File size (upload)",
    "less" : "less",
    "less or equals" : "less or equals",
    "greater or equals" : "greater or equals",
    "greater" : "greater",
    "File system tag" : "File system tag",
    "is tagged with" : "is tagged with",
    "is not tagged with" : "is not tagged with",
    "Select tag…" : "Select tag…",
    "Request remote address" : "Request remote address",
    "matches IPv4" : "matches IPv4",
    "does not match IPv4" : "does not match IPv4",
    "matches IPv6" : "matches IPv6",
    "does not match IPv6" : "does not match IPv6",
    "Request time" : "Request time",
    "between" : "between",
    "not between" : "not between",
    "Start" : "Start",
    "End" : "End",
    "Select timezone…" : "Select timezone…",
    "Request URL" : "Request URL",
    "Predefined URLs" : "Predefined URLs",
    "Files WebDAV" : "Files WebDAV",
    "Request user agent" : "Request user agent",
    "Sync clients" : "Sync clients",
    "Android client" : "Android client",
    "iOS client" : "iOS client",
    "Desktop client" : "Desktop client",
    "User group membership" : "User group membership",
    "is member of" : "is member of",
    "is not member of" : "is not member of",
    "The given operator is invalid" : "The given operator is invalid",
    "The given regular expression is invalid" : "The given regular expression is invalid",
    "The given file size is invalid" : "The given file size is invalid",
    "The given tag id is invalid" : "The given tag id is invalid",
    "The given IP range is invalid" : "The given IP range is invalid",
    "The given IP range is not valid for IPv4" : "The given IP range is not valid for IPv4",
    "The given IP range is not valid for IPv6" : "The given IP range is not valid for IPv6",
    "The given time span is invalid" : "The given time span is invalid",
    "The given start time is invalid" : "The given start time is invalid",
    "The given end time is invalid" : "The given end time is invalid",
    "The given group does not exist" : "The given group does not exist",
    "Check %s is invalid or does not exist" : "Check %s is invalid or does not exist",
    "Operation #%s does not exist" : "Operation #%s does not exist",
    "Operation %s does not exist" : "Operation %s does not exist",
    "Operation %s is invalid" : "Operation %s is invalid",
    "Check %s does not exist" : "Check %s does not exist",
    "Check %s is invalid" : "Check %s is invalid",
    "Check #%s does not exist" : "Check #%s does not exist",
    "Workflow" : "Workflow",
    "Open documentation" : "Open documentation",
    "Add rule group" : "Add rule group",
    "Short rule description" : "Short rule description",
    "Add rule" : "Add rule",
    "Reset" : "Reset",
    "Save" : "Save",
    "Saving…" : "Saving…",
    "Loading…" : "Loading…"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/en_GB.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Unable to retrieve the group list" : "Unable to retrieve the group list",
    "Saved" : "Saved",
    "Saving failed:" : "Saving failed:",
    "File MIME type" : "File MIME type",
    "is" : "is",
    "is not" : "is not",
    "matches" : "matches",
    "does not match" : "does not match",
    "Example: {placeholder}" : "Example: {placeholder}",
    "File size (upload)" : "File size (upload)",
    "less" : "less",
    "less or equals" : "less or equals",
    "greater or equals" : "greater or equals",
    "greater" : "greater",
    "File system tag" : "File system tag",
    "is tagged with" : "is tagged with",
    "is not tagged with" : "is not tagged with",
    "Select tag…" : "Select tag…",
    "Request remote address" : "Request remote address",
    "matches IPv4" : "matches IPv4",
    "does not match IPv4" : "does not match IPv4",
    "matches IPv6" : "matches IPv6",
    "does not match IPv6" : "does not match IPv6",
    "Request time" : "Request time",
    "between" : "between",
    "not between" : "not between",
    "Start" : "Start",
    "End" : "End",
    "Select timezone…" : "Select timezone…",
    "Request URL" : "Request URL",
    "Predefined URLs" : "Predefined URLs",
    "Files WebDAV" : "Files WebDAV",
    "Request user agent" : "Request user agent",
    "Sync clients" : "Sync clients",
    "Android client" : "Android client",
    "iOS client" : "iOS client",
    "Desktop client" : "Desktop client",
    "User group membership" : "User group membership",
    "is member of" : "is member of",
    "is not member of" : "is not member of",
    "The given operator is invalid" : "The given operator is invalid",
    "The given regular expression is invalid" : "The given regular expression is invalid",
    "The given file size is invalid" : "The given file size is invalid",
    "The given tag id is invalid" : "The given tag id is invalid",
    "The given IP range is invalid" : "The given IP range is invalid",
    "The given IP range is not valid for IPv4" : "The given IP range is not valid for IPv4",
    "The given IP range is not valid for IPv6" : "The given IP range is not valid for IPv6",
    "The given time span is invalid" : "The given time span is invalid",
    "The given start time is invalid" : "The given start time is invalid",
    "The given end time is invalid" : "The given end time is invalid",
    "The given group does not exist" : "The given group does not exist",
    "Check %s is invalid or does not exist" : "Check %s is invalid or does not exist",
    "Operation #%s does not exist" : "Operation #%s does not exist",
    "Operation %s does not exist" : "Operation %s does not exist",
    "Operation %s is invalid" : "Operation %s is invalid",
    "Check %s does not exist" : "Check %s does not exist",
    "Check %s is invalid" : "Check %s is invalid",
    "Check #%s does not exist" : "Check #%s does not exist",
    "Workflow" : "Workflow",
    "Files workflow engine" : "Files workflow engine",
    "Open documentation" : "Open documentation",
    "Add rule group" : "Add rule group",
    "Short rule description" : "Short rule description",
    "Add rule" : "Add rule",
    "Reset" : "Reset",
    "Save" : "Save",
    "Saving…" : "Saving…",
    "Loading…" : "Loading…"
},
"nplurals=2; plural=(n != 1);");
